## django-admin
This is a django module based on the MPESA daraja API. Use it to interact with the MPESA API in a simplified manner, abstracting the details for a simple, intuitive usage experience, as well as extensive error handling.

[![Build Status](https://travis-ci.org/martinmogusu/django-daraja.svg?branch=master)](https://travis-ci.org/martinmogusu/django-daraja)

Read the documentation at https://django-admin.readthedocs.io

Daraja API documentation can be found at https://developer.safaricom.co.ke